# Generated by roxygen2: do not edit by hand

export(add_metric_layers)
export(as_bathy)
export(assign_process_groups)
export(balance_samples)
export(bathy_info)
export(blueterra_example)
export(blueterra_examples)
export(blueterra_extdata)
export(blueterra_options)
export(check_bathy_crs)
export(check_bathy_units)
export(create_metric_catalog)
export(crop_bathy)
export(depth_filter)
export(derive_aspect)
export(derive_bpi)
export(derive_curvature)
export(derive_custom_metric)
export(derive_eastness)
export(derive_hillshade)
export(derive_metric_stack)
export(derive_multiscale_bpi)
export(derive_northness)
export(derive_roughness)
export(derive_rugosity)
export(derive_slope)
export(derive_surface_area_ratio)
export(derive_terrain)
export(derive_tpi)
export(derive_tri)
export(estimate_surface_orientation)
export(extend_metric_catalog)
export(extract_cross_sections)
export(extract_isobath_corridors)
export(extract_isobaths)
export(extract_terrain_points)
export(invert_depth)
export(make_isobath_corridors)
export(make_transects)
export(mask_bathy)
export(metric_catalog)
export(pca_axis_labels)
export(plot_bathy)
export(plot_cross_sections)
export(plot_depth_profile)
export(plot_hillshade)
export(plot_isobath_corridors)
export(plot_metric)
export(plot_metric_stack)
export(plot_process_density)
export(plot_process_pca)
export(plot_sampling_rectangles)
export(plot_terrain_map)
export(plot_terrain_summary)
export(plot_transects)
export(prepare_bathy)
export(prepare_model_matrix)
export(process_groups)
export(project_bathy)
export(read_bathy)
export(rename_metric_layers)
export(resample_bathy)
export(sample_terrain_cells)
export(sample_transects)
export(select_process_representatives)
export(set_depth_negative)
export(set_depth_positive)
export(smooth_bathy)
export(standardize_metric_names)
export(summarize_cross_sections)
export(summarize_depth_bands)
export(summarize_isobath_terrain)
export(summarize_process_groups)
export(summarize_terrain)
export(summarize_terrain_by_zone)
export(terrain_correlation)
export(terrain_effect_size)
export(terrain_pca)
export(terrain_pca_by_group)
export(validate_bathy)
export(validate_metric_catalog)
importFrom(rlang,.data)
